TaskRegular<R> class

Inheritance

Constructors

TaskRegular({required String id, required Completer<R> completer, required WorkPriority workPriority, required Execute<R> execution})

Properties

canceled → bool
no setterinherited
completer → Completer<R>
finalinherited
execution → Execute<R>
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
workPriority → WorkPriority
finalinherited

Methods

cancel() → void
inherited
compareTo(covariant Task other) → int
Compares this object to another object.
inherited
complete(R? value, Object? error, StackTrace? st) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(covariant Task other) → bool
The equality operator.
inherited